BenchmarkCase class

A single benchmark test case.

Constructors

BenchmarkCase({required String name, required Future<void> body(), Future<void> setup()?, Future<void> teardown()?})
const

Properties

body Future<void> Function()
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setup Future<void> Function()?
final
teardown Future<void> Function()?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited