BenchmarkSuiteResult class

Result from running a full BenchmarkSuite.

Constructors

BenchmarkSuiteResult({required String suiteName, required List<QueryStats> results, required DateTime runAt})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
results List<QueryStats>
final
runAt DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suiteName String
final

Methods

formatTable() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited