ColumnDefinition class

Definition of a single table column.

Constructors

ColumnDefinition({required String name, required DataType type, ConstraintDefinition constraints = const ConstraintDefinition()})
const
ColumnDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

constraints ConstraintDefinition
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type DataType
final

Methods

copyWith({String? name, DataType? type, ConstraintDefinition? constraints}) ColumnDefinition
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited