FunctionCallExpression class

Inheritance

Constructors

FunctionCallExpression({required String functionName, bool distinct = false, bool isStar = false, Expression? argument, List<Expression>? arguments})
const

Properties

allArguments List<Expression>
All arguments as a list. Returns argument in a list if arguments is null.
no setter
argument Expression?
final
arguments List<Expression>?
final
distinct bool
final
functionName String
final
hashCode int
The hash code for this object.
no setterinherited
isStar bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited