LockManager class abstract

Abstract lock manager interface. Controls concurrent access to table resources.

Implementers

Constructors

LockManager.forMode(DatabaseMode mode)
Factory: creates the appropriate manager for mode.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acquireRead(String resource) Future<void>
acquireWrite(String resource) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseRead(String resource) → void
releaseWrite(String resource) → void
toString() String
A string representation of this object.
inherited
withRead<T>(String resource, Future<T> action()) Future<T>
withWrite<T>(String resource, Future<T> action()) Future<T>

Operators

operator ==(Object other) bool
The equality operator.
inherited