MigrationResult class

Result for a single migration step.

Constructors

MigrationResult({required int version, required String name, required MigrationStatus status, String? errorMessage, Duration? duration})
const

Properties

duration Duration?
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status MigrationStatus
final
success bool
no setter
version int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited