QueryBuilder class

Fluent query builder for convenience wrapping of SQL operations.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() Future<QueryResult>
get() Future<QueryResult>
insert(Map<String, dynamic> values) Future<QueryResult>
limit(int count) QueryBuilder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset(int count) QueryBuilder
orderBy(String column, {bool descending = false}) QueryBuilder
select([List<String>? columns]) QueryBuilder
toString() String
A string representation of this object.
inherited
update(Map<String, dynamic> values) Future<QueryResult>
where(String condition) QueryBuilder

Operators

operator ==(Object other) bool
The equality operator.
inherited