CreateTableStatement class
Constructors
-
CreateTableStatement({required String tableName, bool ifNotExists = false, required List<
ColumnDefinitionNode> columns, List<ForeignKeyConstraintNode> foreignKeys = const [], List<TableLevelConstraintNode> tableConstraints = const []}) -
const
Properties
-
columns
→ List<
ColumnDefinitionNode> -
final
-
foreignKeys
→ List<
ForeignKeyConstraintNode> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ifNotExists → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tableConstraints
→ List<
TableLevelConstraintNode> -
final
- tableName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited