QueryStats class
Statistics for a single query or operation.
Constructors
-
QueryStats({required String label, required int iterations, required List<
Duration> times}) -
const
Properties
- average → Duration
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- iterations → int
-
final
- label → String
-
final
- max → Duration
-
no setter
- median → Duration
-
no setter
- min → Duration
-
no setter
- p95 → Duration
-
no setter
- p99 → Duration
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- throughput → double
-
Operations per second based on total time.
no setter
-
times
→ List<
Duration> -
final
- total → Duration
-
no setter
Methods
-
format(
{String indent = ''}) → String - Returns a human-readable summary line.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited